* Prevent "more" messages from appearing
set more off
* Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR CHAPTER 2 EXAMPLE        *******
*******               CHANGE "filesave" to your directory                *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\14_SPLH861\861_Example3"

* Import chapter 2 data into temporary file
use "$filesave\STATA_Chapter2.dta", clear
* Center continuous predictors
gen age85 = age - 85
gen grip9 = grip - 9
* Creating contrasts for dementia groups
gen demNF=0 
gen demNC=0 
* Demgroup = none   
replace demNF=0 if (demgroup==1)
replace demNC=0 if (demgroup==1)
* Demgroup = future 
replace demNF=1 if (demgroup==2)
replace demNC=0 if (demgroup==2)
* Demgroup = current
replace demNF=0 if (demgroup==3)
replace demNC=1 if (demgroup==3)  
* Labeling new variables
label variable age85  "age85: Age in Years (0=85)"
label variable grip9  "grip9: Grip Strength in Pounds (0=9)"
label variable demNF  "demNF: Dementia Contrast for None=0 vs Future=1"
label variable demNC  "demNC: Dementia Contrast for None=0 vs Current=1"
    
********************************************************************************
*******                       BEGIN EXAMPLE 3 MODELS                     *******
********************************************************************************

* Save results to separate file
log using $filesave\STATA_Example3_Output.log, replace name(STATA_Example3)

display as result "Eq 2.8: Adding Dementia Group"
display as result "Using Manual Group Contrasts so Reference=None"
mixed cognition c.age85 c.grip9 c.sexmw c.demNF c.demNC, ///
                || caseid: , noconstant variance reml,
      test (c.age85=0) (c.grip9=0) (c.sexmw=0) (c.demNF=0) (c.demNC=0) // Model R2 Chi2-Test
      test (c.demNF=0) (c.demNC=0) // Omnibus Chi2-Test for Dementia Group
      lincom _cons*1 + c.demNF*0 + c.demNC*0 // Intercept for None Group
      lincom _cons*1 + c.demNF*1 + c.demNC*0 // Intercept for Future Group
      lincom _cons*1 + c.demNF*0 + c.demNC*1 // Intercept for Current Group
      lincom c.demNF*1  + c.demNC*0  // None   vs Future  Group
      lincom c.demNF*0  + c.demNC*1  // None   vs Current Group
      lincom c.demNF*-1 + c.demNC*1  // Future vs Current Group
	  
display as result "Eq 2.8: Adding Dementia Group" 
display as result "Categorical Predictor for Dementia Group" 
mixed cognition c.age85 c.grip9 c.sexmw i.demgroup, ///
         || caseid: , noconstant variance reml, 
      contrast i.demgroup, // Omnibus Chi2Test for Dementia Group 
      margins  i.demgroup, at(c.age85=0 c.grip9=0 c.sexmw=0) // Get means per group   
      margins  i.demgroup, pwcompare(pveffects), // Pairwise group comparisons
	  
display as result "Eq 2.16: Adding Sex by Dementia Interaction" 
display as result "Categorical Sex and Dementia" 
mixed cognition c.age85 c.grip9 i.sexmw i.demgroup ///
                c.age85#c.grip9 i.sexmw#i.demgroup, ///
                || caseid: , noconstant variance reml, 
	  contrast i.sexmw#i.demgroup // Omnibus interaction Chi2Test
	  margins  i.sexmw#i.demgroup, at(c.age85=0 c.grip9=0) // cell means 
	  margins  i.sexmw#i.demgroup, pwcompare(pveffects), // all cell comparisons
	  margins  i.sexmw@i.demgroup, at(c.age85=0 c.grip9=0) // sex per demgroup
	  margins  i.demgroup@i.sexmw, at(c.age85=0 c.grip9=0) // demgroup per sex
	  contrast {i.sexmw#i.demgroup -1  1  0  1 -1  0} // A: Sex Effect differ btw None, Future?
	  contrast {i.sexmw#i.demgroup -1  1  0  1 -1  0} // A: None-Future Effect differ by Sex?
	  contrast {i.sexmw#i.demgroup -1  0  1  1  0 -1} // B: Sex Effect differ btw None, Current?
	  contrast {i.sexmw#i.demgroup -1  0  1  1  0 -1} // B: None-Current Effect differ by Sex?
	  contrast {i.sexmw#i.demgroup  0 -1  1  0  1 -1} // C: Sex Effect differ btw Future,Current?
	  contrast {i.sexmw#i.demgroup  0 -1  1  0  1 -1} // C: Future-Current Effect differ by Sex?

	    
* Close log
log close STATA_Example3
